fress.impl.buffer


byte-streamcljs

(byte-stream)

IBuffercljsprotocol

getBytecljs

(getByte this index)

getBytescljs

(getBytes this off length)

resetcljs

(reset this)

IBufferReadercljsprotocol

getBytesReadcljs

(getBytesRead this)

notifyBytesReadcljs

(notifyBytesRead this count)

readSignedBytecljs

(readSignedByte this)

readSignedBytescljs

(readSignedBytes this length)

return signed byte view on memory

return signed byte view on memory

readUnsignedBytecljs

(readUnsignedByte this)

readUnsignedBytescljs

(readUnsignedBytes this length)

return unsigned byte view on memory

return unsigned byte view on memory

IBufferWritercljsprotocol

getBytesWrittencljs

(getBytesWritten this)

getFreeCapacitycljs

(getFreeCapacity this)

remaining free bytes to write

remaining free bytes to write

notifyBytesWrittencljs

(notifyBytesWritten this count)

room?cljs

(room? this length)

writeBytecljs

(writeByte this byte)

writeBytescljs

(writeBytes this bytes)
(writeBytes this bytes offset length)

IStreamingWritercljsprotocol

flushTocljs

(flushTo this out)
(flushTo this out offset)

write bytes to externally provided arraybuffer source at the given offset

write bytes to externally provided arraybuffer source at the given offset

toByteArraycljs

(toByteArray this)

get byte-array of current buffer contents. does not close.

get byte-array of current buffer contents. does not close.

readable-buffercljs

(readable-buffer backing)
(readable-buffer backing backing-offset)

Build a BufferReader over a collection of bytes.

Build a BufferReader over a collection of bytes.
raw docstring

with-capacitycljs

(with-capacity n)

writable-buffercljs

(writable-buffer)
(writable-buffer backing)
(writable-buffer backing backing-offset)

Build a BufferWriter over a typed-array. If nil, returns a BytesOutputStream.

Build a BufferWriter over a typed-array. If nil, returns a BytesOutputStream.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries