fress.impl.hopmap


_clearcljs

(_clear this)

_findSlotcljs

(_findSlot this hash)

_getcljs

(_get this k)

@param k, non-null @return the integer associated with k, or -1 if not present

@param k, non-null
@return the integer associated with k, or -1 if not present
raw docstring

_hashcljs

(_hash k)

_interncljs

(_intern this k)

Puts k in the map (if not present) and assigns and returns the index associated with it assigns ints monotonically from 0 @param k, non-null @return the integer associated with k

Puts k in the map (if not present) and assigns and returns the index associated with it
assigns ints monotonically from 0
@param k, non-null
@return the integer associated with k
raw docstring

_oldIndexcljs

(_oldIndex this k)

Puts k in the map if it was not already present. Returns -1 if k was freshly added Returns k's index if k was already in the map. @param k, non-null @return the integer associated with k or -1

Puts k in the map if it was not already present.
Returns -1 if k was freshly added
Returns k's index if k was already in the map.
@param k, non-null
@return the integer associated with k or -1
raw docstring

_resizecljs

(_resize this)

hopmapcljs

(hopmap)
(hopmap capacity)

IHopMapcljsprotocol

clearcljs

(clear this)

findSlotcljs

(findSlot this hash)

interncljs

(intern this k)

isEmptycljs

(isEmpty this)

oldIndexcljs

(oldIndex this k)

resizecljs

(resize this)

cljdoc builds & hosts documentation for Clojure/Script libraries