(build-lookup user-handlers name->map-ctor)(readOpenList this)(readBoolean this)(readInt this)(readObjects- this length)(readClosedList this)(readInt32 this)(readObject this)(getPriorityCache- this)(readAndCacheObject- this cache)(readCount- this)(handleStruct- this tag fields)(readNextCode this)(getHandler- this tag)(read- this code)(lookupCache this cache index)(readFloat this)(getStructCache- this)(validateFooter this)(validateFooter this calculatedLength magicFromStream)(resetCaches this)(readDouble this)(internalRead rdr code)(internalReadBytes rdr length)called on codes/BYTES
called on codes/BYTES
(internalReadChunkedBytes rdr)called on codes/BYTES_CHUNK
called on codes/BYTES_CHUNK
(internalReadChunkedString rdr length)(internalReadDouble rdr code)(internalReadInt rdr code)when throw-on-unsafe? is false, will return a goog.Long for unsafe numbers
when *throw-on-unsafe?* is false, will return a goog.Long for unsafe numbers
(internalReadList rdr length)(internalReadString rdr length)(readBigDecimal rdr _ _)BIGDEC (0xC7) carries two fields: the unscaled value as bytes (a bigint) and an integer scale. Value = unscaled x 10^-scale. Mirrors JVM Fressian's default BigDecimal read; returns a fress.impl.bigdec/Bigdec.
BIGDEC (0xC7) carries two fields: the unscaled value as bytes (a bigint) and an integer scale. Value = unscaled x 10^-scale. Mirrors JVM Fressian's default BigDecimal read; returns a fress.impl.bigdec/Bigdec.
(readBigInt rdr _ _)(readBooleanArray rdr _ _)(readChar rdr _ _)(readDoubleArray rdr _ _)(reader in
&
{:keys [handlers checksum? offset name->map-ctor]
:or {handlers nil checksum? false}
:as opts})(readFloatArray rdr _ _)(readInst rdr _ _)(readIntArray rdr _ _)(readKeyword rdr _ _)(readLongArray rdr _ _)(readMap rdr _ _)(readObjectArray rdr _ _)(readRecord rdr tag component-count name->map-ctor)(readRegex rdr _ _)(readSet rdr _ _)(readSymbol rdr _ _)(readUri rdr _ _)(readUTF8 rdr)this uses TextDecoder on raw utf8 bytes instead of using js on compressed fressian string bytes
this uses TextDecoder on raw utf8 bytes instead of using js on compressed fressian string bytes
(readUUID rdr _ _)(valid-handler-key? k)(valid-name->map-ctor? m)(valid-user-handlers? uh)cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |