fress.writer


*stringify-keys*cljs


*write-raw-utf8*cljs


*write-utf8-tag*cljs


bit-switchcljs

(bit-switch l)

@return {number} bits not needed to represent this number

@return {number} bits not needed to represent this number
raw docstring

buffer-string-chunk-utf8cljs

(buffer-string-chunk-utf8 s start buf)

starting with position start in s, write as much of s as possible into byteBuffer using UTF-8. returns {stringpos, bufpos}

starting with position start in s, write as much of s as possible into byteBuffer
using UTF-8.
returns {stringpos, bufpos}
raw docstring

build-handler-lookupcljs

(build-handler-lookup user-handlers rec->tag)

build-inheritance-lookupcljs

(build-inheritance-lookup handlers)

class-symcljs

(class-sym rec rec->tag)

Record types need a string so the name can survive munging. Is converted to symbol before serializing.

Record types need a string so the name can survive munging. Is converted to
symbol before serializing.
raw docstring

default-write-handlerscljs

@suppress {checkRegExp}

@suppress {checkRegExp}
raw docstring

defaultWriteStringcljs

(defaultWriteString this s)

fullnamecljs

(fullname kw)

IFressianWritercljsprotocol

writeCodecljs

(writeCode this code)

writeStringNoChunk-cljs

(writeStringNoChunk- this s)

writeDoublecljs

(writeDouble this d)

beginClosedListcljs

(beginClosedList this)

writeNullcljs

(writeNull this)

beginOpenListcljs

(beginOpenList this)

getPriorityCachecljs

(getPriorityCache this)

writeBytescljs

(writeBytes this bs)
(writeBytes this bs offset length)

writeCountcljs

(writeCount this n)

writeObjectcljs

(writeObject this o)
(writeObject this o cache?)

shouldSkipCache-cljs

(shouldSkipCache- this o)

writeStringcljs

(writeString this s)

endListcljs

(endList this)

getStructCachecljs

(getStructCache this)

writeListcljs

(writeList this o)

doWrite-cljs

(doWrite- this tag o w cache?)

writeString-cljs

(writeString- this s)

writeFootercljs

(writeFooter this)

writeAscljs

(writeAs this tag o)
(writeAs this tag o cache?)

writeBooleancljs

(writeBoolean this b)

writeFloatcljs

(writeFloat this f)

writeIntcljs

(writeInt this i)

resetCachescljs

(resetCaches this)

clearCachescljs

(clearCaches this)

writeTagcljs

(writeTag this tag componentCount)

internalWriteFootercljs

(internalWriteFooter wrt length)

internalWriteIntcljs

(internalWriteInt wtr n)

normalize-handlerscljs

(normalize-handlers user-handlers)

Normalize type->tag->writer (a la data.fressian) to flat type->writer

Normalize type->tag->writer (a la data.fressian) to flat type->writer
raw docstring

valid-handler-key?cljs

(valid-handler-key? k)

singular or coll of constructors and string tags

singular or coll of constructors and string tags
raw docstring

valid-record->name?cljs

(valid-record->name? m)

each key should be record ctor

each key should be record ctor
raw docstring

valid-user-handlers?cljs

(valid-user-handlers? uh)

write-bigdecimalcljs

(write-bigdecimal wrt x)

BIGDEC = unscaled (bigint, as bytes) + integer scale. Mirrors JVM Fressian's default BigDecimal write; JVM-readable back to a java.math.BigDecimal.

BIGDEC = unscaled (bigint, as bytes) + integer scale. Mirrors JVM Fressian's
default BigDecimal write; JVM-readable back to a java.math.BigDecimal.
raw docstring

write-bigintcljs

(write-bigint wrt n)

writeBigInt64cljs

(writeBigInt64 w n)

written as normal ints where unsafe numbers would be read back as longs

written as normal ints where unsafe numbers would be read back as longs
raw docstring

writeBigInt64Arraycljs

(writeBigInt64Array w arr)

writeBooleanArraycljs

(writeBooleanArray wtr a)

writeByteArraycljs

(writeByteArray wrt bytes)

writeCharcljs

(writeChar wrt s)

writeDoubleArraycljs

(writeDoubleArray wtr a)

writeFloatArraycljs

(writeFloatArray wtr a)

writeInstcljs

(writeInst wtr date)

writeIntArraycljs

(writeIntArray wtr a)

writeLongArraycljs

(writeLongArray wtr arr)

writeMapcljs

(writeMap wrt m)

writeNumbercljs

(writeNumber this n)

writeObjectArraycljs

(writeObjectArray wtr arr)

writercljs

(writer out & {:keys [handlers record->name checksum? offset] :as opts})

Create a writer that combines userHandlers with the normal type handlers built into Fressian.

Create a writer that combines userHandlers with the normal type handlers
built into Fressian.
raw docstring

writeRawUTF8cljs

(writeRawUTF8 this s)

We can use native TextEncoder to remove some dirty work, also chunking is pointless for WASM.

We can use native TextEncoder to remove some dirty work, also chunking is
pointless for WASM.
raw docstring

writeRecordcljs

(writeRecord w rec rec->tag)

writeRegexcljs

(writeRegex wtr re)

writeSetcljs

(writeSet wtr s)

writeUricljs

(writeUri wtr u)

writeUUIDcljs

(writeUUID wtr u)

cljdoc builds & hosts documentation for Clojure/Script libraries