(byte-stream)(getByte this index)(getBytes this off length)(reset this)(getBytesRead this)(notifyBytesRead this count)(readSignedByte this)(readSignedBytes this length)return signed byte view on memory
return signed byte view on memory
(readUnsignedByte this)(readUnsignedBytes this length)return unsigned byte view on memory
return unsigned byte view on memory
(getBytesWritten this)(getFreeCapacity this)remaining free bytes to write
remaining free bytes to write
(notifyBytesWritten this count)(room? this length)(writeByte this byte)(writeBytes this bytes)(writeBytes this bytes offset length)(flushTo this out)(flushTo this out offset)write bytes to externally provided arraybuffer source at the given offset
write bytes to externally provided arraybuffer source at the given offset
(toByteArray this)get byte-array of current buffer contents. does not close.
get byte-array of current buffer contents. does not close.
(readable-buffer backing)(readable-buffer backing backing-offset)Build a BufferReader over a collection of bytes.
Build a BufferReader over a collection of bytes.
(with-capacity n)(writable-buffer)(writable-buffer backing)(writable-buffer backing backing-offset)Build a BufferWriter over a typed-array. If nil, returns a BytesOutputStream.
Build a BufferWriter over a typed-array. If nil, returns a BytesOutputStream.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |