(bit-switch l)@return {number} bits not needed to represent this number
@return {number} bits not needed to represent this number
(buffer-string-chunk-utf8 s start buf)starting with position start in s, write as much of s as possible into byteBuffer using UTF-8. returns {stringpos, bufpos}
starting with position start in s, write as much of s as possible into byteBuffer
using UTF-8.
returns {stringpos, bufpos}(build-handler-lookup user-handlers rec->tag)(build-inheritance-lookup handlers)(class-sym rec rec->tag)Record types need a string so the name can survive munging. Is converted to symbol before serializing.
Record types need a string so the name can survive munging. Is converted to symbol before serializing.
(defaultWriteString this s)(fullname kw)(writeCode this code)(writeStringNoChunk- this s)(writeDouble this d)(beginClosedList this)(writeNull this)(beginOpenList this)(getPriorityCache this)(writeBytes this bs)(writeBytes this bs offset length)(writeCount this n)(writeObject this o)(writeObject this o cache?)(shouldSkipCache- this o)(writeString this s)(endList this)(getStructCache this)(writeList this o)(doWrite- this tag o w cache?)(writeString- this s)(writeFooter this)(writeAs this tag o)(writeAs this tag o cache?)(writeBoolean this b)(writeFloat this f)(writeInt this i)(resetCaches this)(clearCaches this)(writeTag this tag componentCount)(internalWriteFooter wrt length)(internalWriteInt wtr n)(normalize-handlers user-handlers)Normalize type->tag->writer (a la data.fressian) to flat type->writer
Normalize type->tag->writer (a la data.fressian) to flat type->writer
(valid-handler-key? k)singular or coll of constructors and string tags
singular or coll of constructors and string tags
(valid-record->name? m)each key should be record ctor
each key should be record ctor
(valid-user-handlers? uh)(write-bigdecimal wrt x)BIGDEC = unscaled (bigint, as bytes) + integer scale. Mirrors JVM Fressian's default BigDecimal write; JVM-readable back to a java.math.BigDecimal.
BIGDEC = unscaled (bigint, as bytes) + integer scale. Mirrors JVM Fressian's default BigDecimal write; JVM-readable back to a java.math.BigDecimal.
(write-bigint wrt n)(writeBigInt64 w n)written as normal ints where unsafe numbers would be read back as longs
written as normal ints where unsafe numbers would be read back as longs
(writeBigInt64Array w arr)(writeBooleanArray wtr a)(writeByteArray wrt bytes)(writeChar wrt s)(writeDoubleArray wtr a)(writeFloatArray wtr a)(writeInst wtr date)(writeIntArray wtr a)(writeLongArray wtr arr)(writeMap wrt m)(writeNumber this n)(writeObjectArray wtr arr)(writer out & {:keys [handlers record->name checksum? offset] :as opts})Create a writer that combines userHandlers with the normal type handlers built into Fressian.
Create a writer that combines userHandlers with the normal type handlers built into Fressian.
(writeRawUTF8 this s)We can use native TextEncoder to remove some dirty work, also chunking is pointless for WASM.
We can use native TextEncoder to remove some dirty work, also chunking is pointless for WASM.
(writeRecord w rec rec->tag)(writeRegex wtr re)(writeSet wtr s)(writeUri wtr u)(writeUUID wtr u)cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |